/****************************************************************************
** Meta object code from reading C++ file 'lyricsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../audiotube-26.07.90/src/lyricsmodel.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lyricsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11LyricsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto LyricsModel::qt_create_metaobjectdata<qt_meta_tag_ZN11LyricsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LyricsModel",
        "QML.Element",
        "auto",
        "songChanged",
        "",
        "artistChanged",
        "albumChanged",
        "durationChanged",
        "countChanged",
        "fetchLyrics",
        "song",
        "artist",
        "album",
        "duration",
        "count",
        "Role",
        "Line",
        "Start",
        "End"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'songChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'artistChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'fetchLyrics'
        QtMocHelpers::MethodData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'song'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'artist'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'album'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'count'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(15, 15, QMC::EnumFlags{}).add({
            {   16, Role::Line },
            {   17, Role::Start },
            {   18, Role::End },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<LyricsModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject LyricsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LyricsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LyricsModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11LyricsModelE_t>.metaTypes,
    nullptr
} };

void LyricsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LyricsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->songChanged(); break;
        case 1: _t->artistChanged(); break;
        case 2: _t->albumChanged(); break;
        case 3: _t->durationChanged(); break;
        case 4: _t->countChanged(); break;
        case 5: _t->fetchLyrics(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LyricsModel::*)()>(_a, &LyricsModel::songChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LyricsModel::*)()>(_a, &LyricsModel::artistChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LyricsModel::*)()>(_a, &LyricsModel::albumChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LyricsModel::*)()>(_a, &LyricsModel::durationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LyricsModel::*)()>(_a, &LyricsModel::countChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_song; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_artist; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_album; break;
        case 3: *reinterpret_cast<int*>(_v) = _t->m_duration; break;
        case 4: *reinterpret_cast<int*>(_v) = _t->count(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_song, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->songChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_artist, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->artistChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_album, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->albumChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_duration, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->durationChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *LyricsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LyricsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LyricsModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int LyricsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void LyricsModel::songChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LyricsModel::artistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LyricsModel::albumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LyricsModel::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LyricsModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
