#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_audiotube_contents_ui_Main_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_AlbumPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_ArtistPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_PlayerFooter_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_SearchPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_PlaylistPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_ConfirmationMessage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_LibraryPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_MinimizedPlayerControls_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_MaximizedPlayerPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_PlaybackHistory_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_SongMenu_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_ListHeader_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_RoundedImage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_Sidebar_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_NavigationBar_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_SearchHistoryPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_SearchWithDropdown_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_ShareMenu_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_LocalPlaylistPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_LocalPlaylistsPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_PlaylistCover_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_dialogs_PlaylistDialog_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_dialogs_AddPlaylistDialog_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_dialogs_ImportPlaylistDialog_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_dialogs_RenamePlaylistDialog_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_HorizontalCoverView_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_AlbumCoverItem_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_HomeShelf_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_HeroHomeShelf_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_HomePage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_BentoCard_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_HeroCard_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_ExplorePage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_MoodPage_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_components_ActionButton_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}
namespace _qt_qml_org_kde_audiotube_contents_ui_components_DoubleActionButton_qml { 
    extern bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu);
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], &validateLookupSignatures
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/Main.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_Main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/AlbumPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_AlbumPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/ArtistPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_ArtistPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/PlayerFooter.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_PlayerFooter_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/SearchPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_SearchPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/PlaylistPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_PlaylistPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/ConfirmationMessage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_ConfirmationMessage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/LibraryPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_LibraryPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/MinimizedPlayerControls.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_MinimizedPlayerControls_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/MaximizedPlayerPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_MaximizedPlayerPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/PlaybackHistory.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_PlaybackHistory_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/SongMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_SongMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/ListHeader.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_ListHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/RoundedImage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_RoundedImage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/Sidebar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_Sidebar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/NavigationBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_NavigationBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/SearchHistoryPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_SearchHistoryPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/SearchWithDropdown.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_SearchWithDropdown_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/ShareMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_ShareMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/LocalPlaylistPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_LocalPlaylistPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/LocalPlaylistsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_LocalPlaylistsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/PlaylistCover.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_PlaylistCover_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/dialogs/PlaylistDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_dialogs_PlaylistDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/dialogs/AddPlaylistDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_dialogs_AddPlaylistDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/dialogs/ImportPlaylistDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_dialogs_ImportPlaylistDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/dialogs/RenamePlaylistDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_dialogs_RenamePlaylistDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/HorizontalCoverView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_HorizontalCoverView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/AlbumCoverItem.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_AlbumCoverItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/HomeShelf.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_HomeShelf_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/HeroHomeShelf.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_HeroHomeShelf_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/HomePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_HomePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/BentoCard.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_BentoCard_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/HeroCard.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_HeroCard_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/ExplorePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_ExplorePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/MoodPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_MoodPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/components/ActionButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_components_ActionButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/audiotube/contents/ui/components/DoubleActionButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_audiotube_contents_ui_components_DoubleActionButton_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_audiotube)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_audiotube))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_audiotube)() {
    return 1;
}
