/****************************************************************************
** Meta object code from reading C++ file 'userplaylistmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../audiotube-26.07.90/src/userplaylistmodel.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'userplaylistmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17UserPlaylistModelE_t {};
} // unnamed namespace

template <> constexpr inline auto UserPlaylistModel::qt_create_metaobjectdata<qt_meta_tag_ZN17UserPlaylistModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UserPlaylistModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "initialVideoIdChanged",
        "",
        "currentVideoIdChanged",
        "currentIndexChanged",
        "canSkipChanged",
        "canSkipBackChanged",
        "playlistIdChanged",
        "shuffleChanged",
        "lyricsChanged",
        "noLyrics",
        "moveRow",
        "sourceRow",
        "destinationRow",
        "next",
        "previous",
        "skipTo",
        "videoId",
        "playNext",
        "title",
        "std::vector<meta::Artist>",
        "artists",
        "append",
        "clear",
        "clearExceptCurrent",
        "remove",
        "shufflePlaylist",
        "appendPlaylist",
        "PlaylistModel*",
        "playlistModel",
        "appendAlbum",
        "AlbumModel*",
        "albumModel",
        "playFavourites",
        "FavouritesModel*",
        "favouriteModel",
        "shuffled",
        "appendFavourites",
        "playPlaybackHistory",
        "PlaybackHistoryModel*",
        "playbackHistory",
        "appendPlaybackHistory",
        "playLocalPlaylist",
        "LocalPlaylistModel*",
        "appendLocalPlaylist",
        "initialVideoId",
        "playlistId",
        "shuffle",
        "currentVideoId",
        "currentIndex",
        "canSkip",
        "canSkipBack",
        "lyrics",
        "webUrl",
        "QUrl",
        "Role",
        "Title",
        "VideoId",
        "Artists",
        "Album",
        "AlbumId",
        "IsCurrent",
        "Duration"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'initialVideoIdChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentVideoIdChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSkipChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSkipBackChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playlistIdChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lyricsChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noLyrics'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'moveRow'
        QtMocHelpers::MethodData<bool(int, int)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 17 },
        }}),
        // Method 'next'
        QtMocHelpers::MethodData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'previous'
        QtMocHelpers::MethodData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'skipTo'
        QtMocHelpers::MethodData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'playNext'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const std::vector<meta::Artist> &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const std::vector<meta::Artist> &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'clearExceptCurrent'
        QtMocHelpers::MethodData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'remove'
        QtMocHelpers::MethodData<void(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'shufflePlaylist'
        QtMocHelpers::MethodData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'appendPlaylist'
        QtMocHelpers::MethodData<void(PlaylistModel *)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Method 'appendAlbum'
        QtMocHelpers::MethodData<void(AlbumModel *)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Method 'playFavourites'
        QtMocHelpers::MethodData<void(FavouritesModel *, bool)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::Bool, 40 },
        }}),
        // Method 'appendFavourites'
        QtMocHelpers::MethodData<void(FavouritesModel *, bool)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::Bool, 40 },
        }}),
        // Method 'playPlaybackHistory'
        QtMocHelpers::MethodData<void(PlaybackHistoryModel *, bool)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 }, { QMetaType::Bool, 40 },
        }}),
        // Method 'appendPlaybackHistory'
        QtMocHelpers::MethodData<void(PlaybackHistoryModel *, bool)>(45, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 }, { QMetaType::Bool, 40 },
        }}),
        // Method 'playLocalPlaylist'
        QtMocHelpers::MethodData<void(LocalPlaylistModel *, bool)>(46, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 33 }, { QMetaType::Bool, 40 },
        }}),
        // Method 'appendLocalPlaylist'
        QtMocHelpers::MethodData<void(LocalPlaylistModel *, bool)>(48, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 33 }, { QMetaType::Bool, 40 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'initialVideoId'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'playlistId'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'shuffle'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'currentVideoId'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'canSkip'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'canSkipBack'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'lyrics'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'webUrl'
        QtMocHelpers::PropertyData<QUrl>(57, 0x80000000 | 58, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(59, 59, QMC::EnumFlags{}).add({
            {   60, Role::Title },
            {   61, Role::VideoId },
            {   62, Role::Artists },
            {   63, Role::Album },
            {   64, Role::AlbumId },
            {   65, Role::IsCurrent },
            {   66, Role::Duration },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<UserPlaylistModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject UserPlaylistModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractYTMusicModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UserPlaylistModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UserPlaylistModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17UserPlaylistModelE_t>.metaTypes,
    nullptr
} };

void UserPlaylistModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UserPlaylistModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initialVideoIdChanged(); break;
        case 1: _t->currentVideoIdChanged(); break;
        case 2: _t->currentIndexChanged(); break;
        case 3: _t->canSkipChanged(); break;
        case 4: _t->canSkipBackChanged(); break;
        case 5: _t->playlistIdChanged(); break;
        case 6: _t->shuffleChanged(); break;
        case 7: _t->lyricsChanged(); break;
        case 8: _t->noLyrics(); break;
        case 9: { bool _r = _t->moveRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->next(); break;
        case 11: _t->previous(); break;
        case 12: _t->skipTo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->playNext((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::vector<meta::Artist>>>(_a[3]))); break;
        case 14: _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::vector<meta::Artist>>>(_a[3]))); break;
        case 15: _t->clear(); break;
        case 16: _t->clearExceptCurrent(); break;
        case 17: _t->remove((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->shufflePlaylist(); break;
        case 19: _t->appendPlaylist((*reinterpret_cast<std::add_pointer_t<PlaylistModel*>>(_a[1]))); break;
        case 20: _t->appendAlbum((*reinterpret_cast<std::add_pointer_t<AlbumModel*>>(_a[1]))); break;
        case 21: _t->playFavourites((*reinterpret_cast<std::add_pointer_t<FavouritesModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 22: _t->appendFavourites((*reinterpret_cast<std::add_pointer_t<FavouritesModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 23: _t->playPlaybackHistory((*reinterpret_cast<std::add_pointer_t<PlaybackHistoryModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 24: _t->appendPlaybackHistory((*reinterpret_cast<std::add_pointer_t<PlaybackHistoryModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 25: _t->playLocalPlaylist((*reinterpret_cast<std::add_pointer_t<LocalPlaylistModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: _t->appendLocalPlaylist((*reinterpret_cast<std::add_pointer_t<LocalPlaylistModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< std::vector<meta::Artist> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< std::vector<meta::Artist> >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FavouritesModel* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FavouritesModel* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PlaybackHistoryModel* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PlaybackHistoryModel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::initialVideoIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::currentVideoIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::currentIndexChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::canSkipChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::canSkipBackChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::playlistIdChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::shuffleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::lyricsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserPlaylistModel::*)()>(_a, &UserPlaylistModel::noLyrics, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->initialVideoId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->playlistId(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->shuffle(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->currentVideoId(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canSkip(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canSkipBack(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->lyrics(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->webUrl(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInitialVideoId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPlaylistId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setShuffle(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *UserPlaylistModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UserPlaylistModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17UserPlaylistModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractYTMusicModel::qt_metacast(_clname);
}

int UserPlaylistModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractYTMusicModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void UserPlaylistModel::initialVideoIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UserPlaylistModel::currentVideoIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UserPlaylistModel::currentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UserPlaylistModel::canSkipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UserPlaylistModel::canSkipBackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void UserPlaylistModel::playlistIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void UserPlaylistModel::shuffleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void UserPlaylistModel::lyricsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void UserPlaylistModel::noLyrics()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
