// /qt/qml/org/kde/audiotube/contents/ui/RoundedImage.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qhash.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_audiotube_contents_ui_RoundedImage_qml {
QQmlPrivate::AOTLookupValidation::LookupSignatures expectedLookupSignatures()
{
    using namespace Qt::StringLiterals;
    using namespace QQmlPrivate::AOTLookupValidation;
    return {
        { Lookup{ Type{ u""_s, u"QQuickGraphicsInfo"_s, u""_s, IsComposite::No, IsIC::No }, u"api"_s, u""_s }, PropertySignature{ Type{ u""_s, u"QQuickGraphicsInfo::GraphicsApi"_s, u""_s, IsComposite::No, IsIC::No }, 0 } },
        { Lookup{ Type{ u""_s, u"QQuickImage"_s, u""_s, IsComposite::No, IsIC::No }, u"parent"_s, u""_s }, PropertySignature{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, 0 } },
        { Lookup{ Type{ u""_s, u"QQuickImage"_s, u""_s, IsComposite::No, IsIC::No }, u"source"_s, u""_s }, PropertySignature{ Type{ u""_s, u"QUrl"_s, u""_s, IsComposite::No, IsIC::No }, 1 } },
        { Lookup{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, u"implicitWidth"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 39 } },
        { Lookup{ Type{ u""_s, u"QQuickScreenInfo"_s, u""_s, IsComposite::No, IsIC::No }, u"devicePixelRatio"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 10 } },
    };
}

bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu)
{
    enum ValidationState { Pending, Failed, Succeeded };
    static ValidationState state = Pending;
    if (state == Failed)
        return false;
    if (state == Succeeded)
        return true;
    const auto &expectedSignatures = expectedLookupSignatures();
    for (const auto &[lookup, expectedSignature] : expectedSignatures.asKeyValueRange()) {
        if (!QQmlPrivate::AOTLookupValidation::validateLookupSignature(engine, cu, lookup, expectedSignature)) {
            state = Failed;
            return false;
        }
    }
    state = Succeeded;
    return true;
}

extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4f,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd4,0xb,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc7,0x53,0xa1,0xe7,
0xea,0x69,0x72,0x8a,0xd3,0xbf,0x28,0xc8,
0xff,0x4c,0x2e,0x72,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x25,0x0,0x0,0x0,0x20,0x3,0x0,0x0,
0x6,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x8,0x0,0x0,
0x30,0x1,0x0,0x0,0x80,0x1,0x0,0x0,
0xd0,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0x78,0x2,0x0,0x0,0xd0,0x2,0x0,0x0,
0x83,0x0,0x0,0x0,0xa3,0x0,0x0,0x0,
0xd0,0x1,0x0,0x0,0xe3,0x1,0x0,0x0,
0xe3,0x1,0x0,0x0,0xf0,0x1,0x0,0x0,
0x3,0x2,0x0,0x0,0x10,0x2,0x0,0x0,
0x23,0x2,0x0,0x0,0x30,0x2,0x0,0x0,
0x23,0x2,0x0,0x0,0x40,0x2,0x0,0x0,
0x63,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x13,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x15,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1,0x3c,0x2,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x14,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x3,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x17,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x4,0x3c,0x5,
0x18,0x7,0x2e,0x6,0x3c,0x7,0x9c,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x1a,0x0,0xd0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x8,0x3c,0x9,
0x18,0x7,0x2e,0xa,0x3c,0xb,0x6e,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1d,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xc,0x3c,0xd,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0xb8,0x3,0x0,0x0,0xc0,0x3,0x0,0x0,
0xd8,0x3,0x0,0x0,0x0,0x4,0x0,0x0,
0x18,0x4,0x0,0x0,0x40,0x4,0x0,0x0,
0x50,0x4,0x0,0x0,0x60,0x4,0x0,0x0,
0x78,0x4,0x0,0x0,0x90,0x4,0x0,0x0,
0xa0,0x4,0x0,0x0,0xb0,0x4,0x0,0x0,
0xe0,0x4,0x0,0x0,0xf8,0x4,0x0,0x0,
0x8,0x5,0x0,0x0,0x38,0x5,0x0,0x0,
0x50,0x5,0x0,0x0,0x88,0x5,0x0,0x0,
0xc0,0x5,0x0,0x0,0xe0,0x5,0x0,0x0,
0x0,0x6,0x0,0x0,0x10,0x6,0x0,0x0,
0x40,0x6,0x0,0x0,0x58,0x6,0x0,0x0,
0x90,0x6,0x0,0x0,0xc8,0x6,0x0,0x0,
0xd8,0x6,0x0,0x0,0x8,0x7,0x0,0x0,
0x20,0x7,0x0,0x0,0x30,0x7,0x0,0x0,
0x60,0x7,0x0,0x0,0x78,0x7,0x0,0x0,
0x98,0x7,0x0,0x0,0xb0,0x7,0x0,0x0,
0xd8,0x7,0x0,0x0,0xf8,0x7,0x0,0x0,
0x8,0x8,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x57,0x0,0x69,0x0,
0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x69,0x0,0x63,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x72,0x0,0x61,0x0,
0x64,0x0,0x69,0x0,0x75,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x63,0x0,0x68,0x0,0x6f,0x0,0x72,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x4d,0x0,0x6f,0x0,
0x64,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x4d,0x0,0x6f,0x0,0x64,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x2e,0x0,
0x50,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x65,0x0,0x72,0x0,0x76,0x0,0x65,0x0,
0x41,0x0,0x73,0x0,0x70,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x43,0x0,0x72,0x0,
0x6f,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x61,0x0,0x73,0x0,
0x79,0x0,0x6e,0x0,0x63,0x0,0x68,0x0,
0x72,0x0,0x6f,0x0,0x6e,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x53,0x0,0x69,0x0,0x7a,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x77,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x65,0x0,0x6e,0x0,
0x61,0x0,0x62,0x0,0x6c,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x65,0x0,0x6e,0x0,0x61,0x0,
0x62,0x0,0x6c,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x2e,0x0,0x53,0x0,
0x68,0x0,0x61,0x0,0x64,0x0,0x6f,0x0,
0x77,0x0,0x65,0x0,0x64,0x0,0x54,0x0,
0x65,0x0,0x78,0x0,0x74,0x0,0x75,0x0,
0x72,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x6d,0x0,0x61,0x0,
0x73,0x0,0x6b,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x72,0x0,0x61,0x0,0x64,0x0,
0x69,0x0,0x75,0x0,0x73,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x65,0x0,0x66,0x0,
0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x65,0x0,0x72,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x50,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x65,0x0,0x72,0x0,
0x76,0x0,0x65,0x0,0x41,0x0,0x73,0x0,
0x70,0x0,0x65,0x0,0x63,0x0,0x74,0x0,
0x43,0x0,0x72,0x0,0x6f,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x57,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x53,0x0,0x63,0x0,
0x72,0x0,0x65,0x0,0x65,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x76,0x0,0x69,0x0,0x63,0x0,0x65,0x0,
0x50,0x0,0x69,0x0,0x78,0x0,0x65,0x0,
0x6c,0x0,0x52,0x0,0x61,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x47,0x0,0x72,0x0,
0x61,0x0,0x70,0x0,0x68,0x0,0x69,0x0,
0x63,0x0,0x73,0x0,0x49,0x0,0x6e,0x0,
0x66,0x0,0x6f,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x61,0x0,0x70,0x0,
0x69,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x53,0x0,0x6f,0x0,
0x66,0x0,0x74,0x0,0x77,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x8,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x64,0x0,0x0,0x0,
0xf4,0x0,0x0,0x0,0xdc,0x1,0x0,0x0,
0x4c,0x2,0x0,0x0,0xbc,0x2,0x0,0x0,
0x44,0x3,0x0,0x0,0x5,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x74,0x0,0x0,0x0,0x74,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x74,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8c,0x0,0x0,0x0,
0xa,0x0,0x10,0x0,0xb,0x0,0x50,0x0,
0x8c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x2,0x0,0x0,0x20,
0xd,0x0,0x50,0x0,0x8,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0xe,0x0,0xc0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x10,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x6,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x11,0x0,0x90,0x0,
0xe4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x90,0x0,0x16,0x0,0x70,0x1,
0xf,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x15,0x0,0x90,0x0,0x15,0x0,0x30,0x1,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x90,0x0,0x13,0x0,0x10,0x1,
0x1c,0x0,0x0,0x0,0x0,0x0,0xa,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x90,0x0,0x19,0x0,0x90,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0xa,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x90,0x0,0x17,0x0,0x40,0x1,
0xc,0x0,0x0,0x0,0x0,0x0,0xa,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x90,0x0,0x14,0x0,0x10,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x14,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x10,0x1,0x14,0x0,0x70,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x17,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x40,0x1,0x17,0x0,0xb0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x19,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0xd0,0x0,0x1b,0x0,0x50,0x1,
0x16,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0xd0,0x0,0x1a,0x0,0x60,0x1,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x1b,0x0,0x50,0x1,0x1c,0x0,0x10,0x1,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x10,0x1,0x1d,0x0,0x90,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for source at line 19, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QUrl v2_0;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(0, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = std::move(s.v2_0);
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fillMode at line 21, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(2, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(2, []() { static const auto t = QMetaType::fromName("QQuickImage*"); return t; }().metaObject(), "FillMode", "PreserveAspectCrop");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_2);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickItem*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fill at line 20, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(3, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_0;
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<int>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for width at line 23, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_6 = nullptr;
double v2_2_v7_4;
double v2_8;
int v2_10;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(4, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(5, s.v2_0, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookupAsVariant(5, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
s.v2_2_v7_4 = aotContext->engine->fromVariant<double>(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->loadAttachedLookup(6, aotContext->qmlScopeObject, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initLoadAttachedLookup(6, QQmlPrivate::AOTCompiledContext::InvalidStringId, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getObjectLookup(7, s.v2_6, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetObjectLookup(7, s.v2_6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
{
}
// generate_Mul
s.v2_10 = QJSNumberCoercion::toInteger((s.v2_2_v7_4 * s.v2_8));
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<int *>(argv[0]) = s.v2_10;
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for enabled at line 26, column 13
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
bool v2_10;
int v2_2_v7_4;
int v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadAttachedLookup(8, aotContext->qmlScopeObject, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadAttachedLookup(8, QQmlPrivate::AOTCompiledContext::InvalidStringId, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(9, s.v2_0, &s.v2_2_v7_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(9, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getEnumLookup(11, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetEnumLookup(11, []() { static const auto t = QMetaType::fromName("QQuickGraphicsInfo*"); return t; }().metaObject(), "GraphicsApi", "Software");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_CmpStrictNotEqual
s.v2_10 = s.v2_2_v7_4 != s.v2_8;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_10;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
